summaryrefslogtreecommitdiff
path: root/settings.py
diff options
context:
space:
mode:
Diffstat (limited to 'settings.py')
-rw-r--r--settings.py24
1 files changed, 12 insertions, 12 deletions
diff --git a/settings.py b/settings.py
index 8cde6342..98819250 100644
--- a/settings.py
+++ b/settings.py
@@ -1,5 +1,5 @@
import os
# Django settings for archweb project.
## Set the debug values
DEBUG = False
@@ -13,7 +13,7 @@ ADMINS = ()
MANAGERS = ADMINS
# Package out-of-date emails for orphans
-NOTIFICATIONS = ['arch-notifications@archlinux.org']
+NOTIFICATIONS = ['dev@lists.parabolagnulinux.org']
# Full path to the data directory
DEPLOY_PATH = os.path.dirname(os.path.realpath(__file__))
@@ -130,23 +130,23 @@ INSTALLED_APPS = (
PGP_SERVER = 'pgp.mit.edu:11371'
# URL to fetch a current list of available ISOs
-ISO_LIST_URL = 'http://releng.archlinux.org/isos/'
+ISO_LIST_URL = 'https://repo.parabolagnulinux.org/isos/'
# URL to the PXE netboot instructions
-PXEBOOT_URL = 'http://releng.archlinux.org/pxeboot/'
+PXEBOOT_URL = 'http://repo.parabolagnulinux.org/pxeboot/'
# URL for SVN access for fetching commit messages (note absence of packages or
# community bit on the end, repo.svn_root is appended)
-SVN_BASE_URL = 'svn://svn.archlinux.org/'
+#SVN_BASE_URL = 'svn://svn.archlinux.org/'
-MAILMAN_BASE_URL = 'https://mailman.archlinux.org/'
-BUGTRACKER_URL = 'https://bugs.archlinux.org/'
+MAILMAN_BASE_URL = 'https://lists.parabolagnulinux.org/'
+BUGTRACKER_URL = 'https://labs.parabola.nu/'
-BRANDING_APPNAME = 'archweb'
-BRANDING_DISTRONAME = 'Arch Linux'
-BRANDING_SHORTNAME = 'Arch'
-BRANDING_WIKINAME = 'ArchWiki'
-BRANDING_EMAIL = 'Arch Website Notification <nobody@archlinux.org>'
+BRANDING_APPNAME = 'parabolaweb'
+BRANDING_DISTRONAME = 'Parabola GNU/Linux-libre'
+BRANDING_SHORTNAME = 'Parabola'
+BRANDING_WIKINAME = 'ParabolaWiki'
+BRANDING_EMAIL = 'Parabola Website Notification <nobody@parabolagnulinux.org>'
## Import local settings
@@ -1,5 +1,5 @@
import os
-# Django settings for archweb project.
+# Django settings for parabolaweb project.
## Set the debug values
DEBUG = False